**This changelog was started at 6/3/24**
- [home](/README.md)

***

# v0.1.18
**6/4/24**
- Added the working asymmetrical encryption to server/client communications, and improved how strings are interpreted into types (dictionary, tuple, etc).
- Commit label: [9be25a4](https://github.com/SketchedDoughnut/lynxy/tree/9be25a425ff833e5490de4871f6abd8daef7861b)

# v0.1.19
**6/4/24**
- Added the distribution feature to the server properly, with some minor handling. It is still an experimental feature and can't be fully relied on. However, encryption works fine!
- Commit label: [ea66aaf](https://github.com/SketchedDoughnut/lynxy/tree/ea66aaf00874fe0cd29bfe06b442dad93de62a41)

# V0.2.0 - 0.2.14
**1/4/25**
- These releases were the first ones in a while, as the entirety of Lynxy has been refactored and rewritten to be simpler, more lightweight, and quicker. The lynxy_server addition has been dropped, but a server implementation might be made in the future. More information will be shared in the official release when the documentation is out (This is being written before documentation is complete).
- Commit Label: [85da65c](https://github.com/SketchedDoughnut/lynxy/tree/85da65c59e60e8c78fe3d33704d09e4bb5be0eb3)